library(tidyverse)
library(hypervolume)
setwd("~/PIERRE")

load("HOLES_HYPERVOL/results/scaling_factor.Rdata")
load("HOLES_HYPERVOL/results/regional_volume_list.Rdata")

load("HOLES_HYPERVOL/results/local_hypervolumes_list.Rdata")
load("HOLES_HYPERVOL/results/community_hypervolumes_list.Rdata")

load("regional_hypervolumes_list.Rdata")
load("local_hypervolumes_list.Rdata")
load("community_hypervolumes_list.Rdata")


# limits_for_plot <- list("La" = c(-3,5), "G" = c(-3,5), "HMax" = c(-3,5), DDMin = c(-3,3)) 

################### we loop through the 11 sites ############################### 

# create list of sites
sites_list <- list.files(path="Capsis_dev_2/data/forceps/pierre", full.names = T, pattern="output-cmd2_PG_*") %>% 
  str_sub(start = 49, end = -5)

volumes_stats <- data.frame(pool = rep(c("regional","local", "community"), each = length(sites_list)), 
                            site = rep(sites_list,3), 
                            hollow_vol = NA, 
                            filled_vol = NA, 
                            hollowness_ratio = NA)

#iterations through site list
# site <- "GrandeDixence"
for(site in sites_list){
  print(site)
  
  ############## Regional #####################
  # compute volume statistics
  regional_volumes <- get_volume(regional_hypervolumes_list[[site]])
  
  # extract volume statistics
  volumes_stats[volumes_stats$pool == "regional" & volumes_stats$site == site, "hollow_vol"] <- 
    sum(regional_volumes[-1])
  
  volumes_stats[volumes_stats$pool == "regional" & volumes_stats$site == site, "filled_vol"] <- 
    regional_volumes[1]
  
  volumes_stats[volumes_stats$pool == "regional" & volumes_stats$site == site, "hollowness_ratio"] <- 
    sum(regional_volumes[-1]) / reg_volumes[2]

############## local #####################
# compute volume statistics
local_volumes <- get_volume(local_hypervolumes_list[[site]])

# extract volume statistics
volumes_stats[volumes_stats$pool == "local" & volumes_stats$site == site, "hollow_vol"] <- 
  sum(local_volumes[-1])

volumes_stats[volumes_stats$pool == "local" & volumes_stats$site == site, "filled_vol"] <- 
  local_volumes[1]

volumes_stats[volumes_stats$pool == "local" & volumes_stats$site == site, "hollowness_ratio"] <- 
  sum(local_volumes[-1]) / reg_volumes[2]

# plot holes
# png(filename = paste("HOLES_HYPERVOL/results/hypervolumes_local_",site,".png", sep = ""), width=1500, height = 1500,  res=200)
# plot(hypervolume_join(c(regional_volumes_list@HVList$Reg.Conv.Expectation,
#                         # regional_volumes_list@HVList$Regional.Hypervol,
#                         site_volumes_list@HVList[1],
#                         site_volumes_list@HVList[2:length(site_volumes_list@HVList)])),
#      limits = c(-3.5,5),
#      colors = c("lightblue", "darkblue","red1", "red2", "red3", "red4", "darkred"),
#      cex.names = 3, cex.centroid = 2,
#      cex.random = 0.25, show.data = F)
# dev.off()


############ community ################
# compute volume statistics
comm_volumes <- get_volume(community_hypervolumes_list[[site]])


# extract volume statistics
volumes_stats[volumes_stats$pool == "community" & volumes_stats$site == site, "hollow_vol"] <- 
  sum(comm_volumes[-1])

volumes_stats[volumes_stats$pool == "community" & volumes_stats$site == site, "filled_vol"] <- 
  comm_volumes[1]

volumes_stats[volumes_stats$pool == "community" & volumes_stats$site == site, "hollowness_ratio"] <- 
  sum(comm_volumes[-1]) / local_volumes[1]


# plot holes
# png(filename = paste("HOLES_HYPERVOL/results/hypervolumes_community_",site,".png", sep = ""), width=1500, height = 1500,  res=200)
# 
# plot(hypervolume_join(c(regional_volumes_list@HVList$Reg.Conv.Expectation,
#                         local_hypervolumes_list[[site]][[1]],
#                         community_volumes_list@HVList[2:length(community_volumes_list@HVList)])),
#      limits = c(-3.5,5.5),
#      colors = c("lightblue","darkblue","red1", "red2", "red3", "red4", "darkred"),
#      cex.names = 3, cex.centroid = 2,
#      cex.random = 0.25, show.data = F)
# 
# dev.off()
}

volumes_stats[volumes_stats$site == "Sion" & volumes_stats$pool == "community",4:5] <- 0
levels(volumes_stats$pool)
volumes_stats$pool <- factor(volumes_stats$pool, levels=rev(levels(volumes_stats$pool)))

# volumes_stats <- volumes_stats[volumes_stats$site != "Sion",]
# volumes_stats$site <- levels(volumes_stats$site)

sites_conditions <- read.csv2("HOLES_HYPERVOL/resources/sites_forceps.csv")
for(i in 2:length(sites_conditions)){ sites_conditions[,i] <- as.numeric(as.character(sites_conditions[,i]))}

vol_sites <- left_join(volumes_stats, sites_conditions)
colnames(vol_sites)[6] <-"latitude"

save(vol_sites, file = "HOLES_HYPERVOL/results/volumes_sites.Rdata")

###see figures script for figure 5

###see figures script for figure 6


# png("HOLES_HYPERVOL/results/hollow_fraction.png", width=2000, height = 1000,  res=200)
# ggplot(vol_sites, aes(y = hollowness_ratio, x=mean_temp)) +
#   geom_hline(yintercept = regional_hollowness_ratio, colour="lightblue", size=2)+
#   geom_vline(aes(xintercept = max_productivity), col="grey90", size=2)+
#   geom_point(aes(fill=pool),col="grey70", shape=21, size=4)+
#   geom_text(aes(label=site),y=0.1, angle=90, size=4)+
#   # facet_wrap(~pool, ncol=1) + 
#   labs(x="Maximum productivity (t.ha−1.year−1)", 
#        y="Hollow volume ratio", 
#        fill = "level")+
#   ylim(0,0.75)+
#   scale_fill_viridis_d()+
#   theme_classic()+
#   theme(legend.position = "bottom")
# dev.off()

########### describe holes along trait axis #############
holesRandomPoints_regional_list <- regional_hypervolumes_list %>% map(function(hv_sit){map(hv_sit@HVList, function(hv){hv@RandomPoints})})
holesRandomPoints_regional_df <- plyr::ldply(holesRandomPoints_regional_list[[sites_list[1]]])
for(site in sites_list[-1]){
holesRandomPoints_regional_df <- rbind(holesRandomPoints_regional_df, plyr::ldply(holesRandomPoints_regional_list[[site]]))}

holesRandomPoints_local_list <- local_hypervolumes_list %>% map(function(hv_sit){map(hv_sit@HVList, function(hv){hv@RandomPoints})})
holesRandomPoints_local_df <- plyr::ldply(holesRandomPoints_local_list[[sites_list[1]]])
for(site in sites_list[-1]){
holesRandomPoints_local_df <- rbind(holesRandomPoints_local_df, plyr::ldply(holesRandomPoints_local_list[[site]]))}


holesRandomPoints_community_list <- community_hypervolumes_list[-11] %>% map(function(hv_sit){map(hv_sit@HVList, function(hv){hv@RandomPoints})})
holesRandomPoints_community_df <- plyr::ldply(holesRandomPoints_community_list[[sites_list[1]]])
for(site in sites_list[-1]){
  holesRandomPoints_community_df <- rbind(holesRandomPoints_community_df, plyr::ldply(holesRandomPoints_community_list[[site]]))}

holesRandomPoints <- rbind(holesRandomPoints_regional_df, holesRandomPoints_local_df, holesRandomPoints_community_df)

holesRandomPoints$.id <- as.factor(holesRandomPoints$.id)
holesRandomPoints$site <- as.factor(word(holesRandomPoints$.id , -1))
holesRandomPoints$pool <- as.factor(word(holesRandomPoints$.id , 1))
holesRandomPoints$type <- as.factor(word(holesRandomPoints$.id , 2))

holesRandomPoints$pool[holesRandomPoints$pool == "regional"] <- "Regional"
holesRandomPoints$pool <- droplevels(holesRandomPoints$pool)
levels(holesRandomPoints$pool) <- c("community", "local", "regional")


holesRandomPoints$La.    <- holesRandomPoints$La * scaling_factor_10000ind[["La","sigma"]] + scaling_factor_10000ind[["La","mu"]]
holesRandomPoints$G.     <- holesRandomPoints$G  * scaling_factor_10000ind[["G","sigma"]]  + scaling_factor_10000ind[["G","mu"]]
holesRandomPoints$HMax.  <- holesRandomPoints$HMax  * scaling_factor_10000ind[["HMax","sigma"]] + scaling_factor_10000ind[["HMax","mu"]]
holesRandomPoints$DDMin. <- holesRandomPoints$DDMin * scaling_factor_10000ind[["DDMin","sigma"]] + scaling_factor_10000ind[["DDMin","mu"]]

load("HOLES_HYPERVOL/results/volumes_sites.Rdata")
holesRandomPoints <- left_join(holesRandomPoints, vol_sites)
holesRandomPoints$pool <- as.factor(holesRandomPoints$pool)
levels(holesRandomPoints$pool)
holesRandomPoints$pool <- factor(holesRandomPoints$pool, levels=rev(levels(holesRandomPoints$pool)))

save(holesRandomPoints, file = "HOLES_HYPERVOL/results/holesRandomPoints_withSitesConditions.Rdata")

library(see)

svg("HOLES_HYPERVOL/results/holes_description_DDMin.svg", width=6, height = 8)
ggplot(holesRandomPoints[holesRandomPoints$type != "Hypervolume",], aes(y = DDMin., x = fct_reorder(site, mean_temp)))+
  geom_violinhalf(aes(fill = pool), col=NA, scale="count")+
  geom_violinhalf(data = holesRandomPoints[holesRandomPoints$type == "Hypervolume",], aes(y = DDMin., x = fct_reorder(site, mean_temp)), col=NA, fill ="darkgrey", alpha=0.5, scale="count")+
  scale_fill_viridis_d(guide = F)+
  facet_wrap(~pool)+
  coord_flip()+
  theme_modern()
dev.off()

load("HOLES_HYPERVOL/results/regional_volume_list.Rdata")
load("HOLES_HYPERVOL/results/scaling_factor.Rdata")


svg("HOLES_HYPERVOL/results/holes_description_G.svg", width=6, height = 8)
ggplot(holesRandomPoints[holesRandomPoints$type != "Hypervolume",], aes(y = G., x = fct_reorder(site, mean_temp)))+
  geom_violinhalf(aes(fill = pool), col=NA, scale="count")+
  geom_violinhalf(data = holesRandomPoints[holesRandomPoints$type == "Hypervolume",], aes(y = G., x = fct_reorder(site, mean_temp)), col=NA, fill ="darkgrey", alpha=0.5, scale="count")+
  scale_fill_viridis_d(guide = F)+
  facet_wrap(~pool)+
  coord_flip()+
  theme_modern()
dev.off()

svg("HOLES_HYPERVOL/results/holes_description_HMax.svg", width=6, height = 8)
ggplot(holesRandomPoints[holesRandomPoints$type != "Hypervolume",], aes(y = HMax., x = fct_reorder(site, mean_temp)))+
  geom_violinhalf(aes(fill = pool), col=NA, scale="count")+
  geom_violinhalf(data = holesRandomPoints[holesRandomPoints$type == "Hypervolume",], aes(y = HMax., x = fct_reorder(site, mean_temp)), col=NA, fill ="darkgrey", alpha=0.5, scale="count")+
  scale_fill_viridis_d(guide = F)+
  facet_wrap(~pool)+
  coord_flip()+
  theme_modern()
dev.off()


svg("HOLES_HYPERVOL/results/sites_temperature.svg", width=4, height = 8)
ggplot(vol_sites[vol_sites$pool == "local",], aes(y = mean_temp, x =  fct_reorder(site, mean_temp) ))+
  geom_point()+
  geom_line(aes(group = 1))+
  theme_modern()+
  coord_flip()
dev.off()


############# other possibility for figure 6 ###############
## create vector of random points from convex expectation 


convexExpectationRandomPoints <- sample_n(as.data.frame(regional_volumes_list@HVList$Reg.Conv.Expectation@RandomPoints),5000)
convexExpectationRandomPoints$La.    <- convexExpectationRandomPoints$La * scaling_factor_10000ind[["La","sigma"]] + scaling_factor_10000ind[["La","mu"]]
convexExpectationRandomPoints$G.     <- convexExpectationRandomPoints$G  * scaling_factor_10000ind[["G","sigma"]]  + scaling_factor_10000ind[["G","mu"]]
convexExpectationRandomPoints$HMax.  <- convexExpectationRandomPoints$HMax  * scaling_factor_10000ind[["HMax","sigma"]] + scaling_factor_10000ind[["HMax","mu"]]
convexExpectationRandomPoints$DDMin. <- convexExpectationRandomPoints$DDMin * scaling_factor_10000ind[["DDMin","sigma"]] + scaling_factor_10000ind[["DDMin","mu"]]
convexExpectationRandomPoints <- rbind(convexExpectationRandomPoints, convexExpectationRandomPoints, convexExpectationRandomPoints, convexExpectationRandomPoints, convexExpectationRandomPoints, convexExpectationRandomPoints, convexExpectationRandomPoints, convexExpectationRandomPoints, convexExpectationRandomPoints, convexExpectationRandomPoints, convexExpectationRandomPoints)
convexExpectationRandomPoints$site <- rep(sites_list, each = 5000)

ggplot() +
  geom_violinhalf(data = convexExpectationRandomPoints, 
                  aes(y = HMax., x=site), col=NA, fill ="grey", scale="count")+
  geom_violinhalf(data = holesRandomPoints[holesRandomPoints$type != "Hypervolume" & holesRandomPoints$pool == "regional",], 
                  aes(y = HMax., x = fct_reorder(site, mean_temp)), col=NA, fill = viridis(30)[1], scale="count", alpha = 0.75)+
  geom_violinhalf(data = holesRandomPoints[holesRandomPoints$type != "Hypervolume" & holesRandomPoints$pool == "local",], 
                  aes(y = HMax., x = fct_reorder(site, mean_temp)), col=NA, fill = viridis(30)[15], scale="count", alpha = 0.75)+
  geom_violinhalf(data = holesRandomPoints[holesRandomPoints$type != "Hypervolume" & holesRandomPoints$pool == "community",], 
                  aes(y = HMax., x = fct_reorder(site, mean_temp)), col=NA, fill = viridis(30)[30], scale="count", alpha = 0.75)+

  # scale_fill_viridis_d(guide = F)+
  # facet_wrap(~pool)+
  coord_flip()+
  theme_modern()


ggplot() +
  geom_violinhalf(data = convexExpectationRandomPoints, 
                  aes(y = G., x=site), col=NA, fill ="darkgrey", scale="count")+
  geom_violinhalf(data = holesRandomPoints[holesRandomPoints$type != "Hypervolume" & holesRandomPoints$pool == "regional",], 
                  aes(y = G., x = fct_reorder(site, mean_temp)), col=NA, fill = viridis(30)[1], scale="count", alpha = 0.75)+
  geom_violinhalf(data = holesRandomPoints[holesRandomPoints$type != "Hypervolume" & holesRandomPoints$pool == "local",], 
                  aes(y = G., x = fct_reorder(site, mean_temp)), col=NA, fill = viridis(30)[15], scale="count", alpha = 0.75)+
  geom_violinhalf(data = holesRandomPoints[holesRandomPoints$type != "Hypervolume" & holesRandomPoints$pool == "community",], 
                  aes(y = G., x = fct_reorder(site, mean_temp)), col=NA, fill = viridis(30)[30], scale="count", alpha = 0.75)+
  # scale_fill_viridis_d(guide = F)+
  # facet_wrap(~pool)+
  coord_flip()+
  theme_modern()

ggplot() +
  geom_violinhalf(data = convexExpectationRandomPoints, aes(y = La., x=site), col=NA, fill ="darkgrey", scale="count")+
  geom_violinhalf(data = holesRandomPoints[holesRandomPoints$type != "Hypervolume" & holesRandomPoints$pool == "regional",], 
                  aes(y = La., x = fct_reorder(site, mean_temp)), col=NA, fill = viridis(30)[1], scale="count", alpha = 0.75)+
  geom_violinhalf(data = holesRandomPoints[holesRandomPoints$type != "Hypervolume" & holesRandomPoints$pool == "local",], 
                  aes(y = La., x = fct_reorder(site, mean_temp)), col=NA, fill = viridis(30)[15], scale="count", alpha = 0.75)+
  geom_violinhalf(data = holesRandomPoints[holesRandomPoints$type != "Hypervolume" & holesRandomPoints$pool == "community",], 
                  aes(y = La., x = fct_reorder(site, mean_temp)), col=NA, fill = viridis(30)[30], scale="count", alpha = 0.75)+
  # scale_fill_viridis_d(guide = F)+
  # facet_wrap(~pool)+
  coord_flip()+
  theme_modern()


ggplot() +
  geom_violinhalf(data = convexExpectationRandomPoints, aes(y = DDMin., x=site), col=NA, fill ="darkgrey", scale="count")+
  geom_violinhalf(data = holesRandomPoints[holesRandomPoints$type != "Hypervolume" & holesRandomPoints$pool == "regional",], 
                  aes(y = DDMin., x = fct_reorder(site, mean_temp)), col=NA, fill = viridis(30)[1], scale="count", alpha = 0.75)+
  geom_violinhalf(data = holesRandomPoints[holesRandomPoints$type != "Hypervolume" & holesRandomPoints$pool == "local",], 
                  aes(y = DDMin., x = fct_reorder(site, mean_temp)), col=NA, fill = viridis(30)[15], scale="count", alpha = 0.75)+
  geom_violinhalf(data = holesRandomPoints[holesRandomPoints$type != "Hypervolume" & holesRandomPoints$pool == "community",], 
                  aes(y = DDMin., x = fct_reorder(site, mean_temp)), col=NA, fill = viridis(30)[30], scale="count", alpha = 0.75)+
  # scale_fill_viridis_d(guide = F)+
  # facet_wrap(~pool)+
  coord_flip()+
  theme_modern()


ggplot(holesRandomPoints[holesRandomPoints$type != "Hypervolume",], aes(y = HMax., x = mean_temp, col = pool))+
  stat_smooth(method="lm", col="black")+
  stat_summary(geom = 'pointrange')+
  scale_color_viridis_d(guide = F)+
  facet_wrap(~pool)+
  
  # coord_flip()+
  theme_modern()
mod <- 

ggplot(holesRandomPoints[holesRandomPoints$type != "Hypervolume",], aes(y = DDMin., x = mean_temp, col = pool))+
  stat_smooth(method="lm", col="black")+
  stat_summary(geom = 'pointrange')+
  scale_color_viridis_d(guide = F)+
  facet_wrap(~pool)+
  # coord_flip()+
  theme_modern()


ggplot(holesRandomPoints[holesRandomPoints$type != "Hypervolume",], aes(y = G., x = mean_temp, col = pool))+
  stat_smooth(method="lm", col="black")+
  stat_summary(geom = 'pointrange')+
  scale_color_viridis_d(guide = F)+
  facet_wrap(~pool)+
  # coord_flip()+
  theme_modern()



mod <- lm(G. ~ mean_temp, data = holesRandomPoints[holesRandomPoints$pool == "regional", ])
summary(mod)
plot(mod)

mod <- lm(G. ~ mean_temp, data = holesRandomPoints[holesRandomPoints$pool == "community", ])
summary(mod)



ggplot(holesRandomPoints[holesRandomPoints$type != "Hypervolume",], aes(y = HMax., x = mean_temp, col = pool))+
  stat_summary(fun.data = 'mean_sdl', geom = 'pointrange')+
  scale_color_viridis_d(guide = F)+
  facet_wrap(~pool)+
  theme_modern()

  